@@ -4,7 +4,7 @@ from TextPreprocessing.utility import process_text
 class preprocess:
     
     def __init__(self):
-        self.__version__ = "3.1.1"
+        self.__version__ = "3.1.2"
         self.obj = process_text()
         self.start = 1
     
@@ -16,6 +16,10 @@ class preprocess:
 
     def clean_entities(self, text):
         return self.obj.clear_generic_entity(text)
+    
+    def clear_email_address(self, text):
+        return self.obj.clear_email_id(text)
+
 
 
     def cleanup(self, text, end):
